@@ -3,17 +3,18 @@
 import json
 import logging
 import socket
+from typing import Optional
 
 from graylogging.tools import validate_gelf_payload
 
 
-class TCPGELF(object):
-    def __init__(self, host, port, debug=False):
+class TCPGELF:
+    def __init__(self, host: str, port: Optional[int] = 12201) -> None:
         self.host = host
         self.port = port
         self.logger = logging.getLogger(__name__)
 
-    def push_log(self, payload: dict):
+    def push_log(self, payload: dict) -> None:
         """
         Sends a message to Graylog using GELF over TCP.
 
@@ -30,13 +31,11 @@ class TCPGELF(object):
             try:
                 s.sendall(log + b"\0")
             except OSError:
-                self.logger.exception(
-                    "Failed to send the following log entry: %s", log
-                )
+                self.logger.exception("Failed to send the following log entry: %s", log)
                 pass
             s.shutdown(1)
 
-    def send_gelf(self, payload: dict):
+    def send_gelf(self, payload: dict) -> None:
         """"""
         if validate_gelf_payload(payload):
             return self.push_log(payload)
